{
  inputs = {
    lix = {
      url = "git+https://git@git.lix.systems/lix-project/lix?ref=refs/tags/2.90-beta.1";
      flake = false;
    };
    lix-module = {
      url = "git+https://git.lix.systems/lix-project/nixos-module";
      inputs.lix.follows = "lix";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nixpkgs.url = "nixpkgs/nixos-23.11";
    nixos-hardware.url = "github:NixOS/nixos-hardware/master";
  };

  outputs = { self, lix-module, nixpkgs, nixos-hardware, ... }@attrs: {
    nixosConfigurations.firestar = nixpkgs.lib.nixosSystem {
      system = "x86_64-linux";
      specialArgs = attrs;
      modules = [
        lix-module.nixosModules.default
        nixos-hardware.nixosModules.common-gpu-amd
        ./desktop.nix
        ./firestar
        ./fonts.nix
        ./lix-cache.nix
        ./packages.nix
          (import ./user.nix {
          name = "Aode";
          authorizedKeys = [
            "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILojJubDCB2Mc4fw2mdp5Lzg5mTifXwawIVuyb3vr4lB asonix@graystripe"
          ];
        })
        {
          services.openssh = {
            enable = true;
            settings.PermitRootLogin = "no";
          };
        }
      ];
    };
    nixosConfigurations.graystripe = nixpkgs.lib.nixosSystem {
      system = "x86_64-linux";
      specialArgs = attrs;
      modules = [
        lix-module.nixosModules.default
      	nixos-hardware.nixosModules.framework-11th-gen-intel
        ./desktop.nix
        ./fonts.nix
        ./graystripe
        ./lix-cache.nix
        ./packages.nix
        (import ./user.nix { name = "Tavi"; })
        {
          services.openssh = {
            enable = true;
            settings.PermitRootLogin = "no";
          };
        }
      ];
    };
    nixosConfigurations.squirrelflight = nixpkgs.lib.nixosSystem {
      system = "x86_64-linux";
      specialArgs = attrs;
      modules = [
        lix-module.nixosModules.default
        nixos-hardware.nixosModules.framework-16-7040-amd
        ./desktop.nix
        ./fonts.nix
        ./lix-cache.nix
        ./packages.nix
        ./squirrelflight
        (import ./user.nix { name = "Tavi"; })
        {
          services.openssh = {
            enable = true;
            settings.PermitRootLogin = "no";
          };
        }
      ];
    };
  };
}
